--------------------------------------------------------------------------------
--
-- Title       : DecoderDigDef_InxOut
-- Design      : DecoderDigDef_InxOut
-- Author      : Alex Shtengel
-- Company     : Home
--------------------------------------------------------------------------------
-- File        : DecoderDigDef_InxOut.vhd
-- Generated   : Mar 25  2004
--------------------------------------------------------------------------------
-- Description : Decoder with rise output
--------------------------------------------------------------------------------
-- Revision History :
-- -----------------------------------------------------------------------------
--   Ver  :| Author            :| Mod. Date :|    Changes Made:
--   v1.1  | Alex Shtengel	   :| 12/06/20	:| Automatically Generated
-- -----------------------------------------------------------------------------
library ieee ;

use ieee.std_logic_1164.all ;
use ieee.std_logic_arith.all;
use ieee.std_logic_unsigned.all;

entity DecoderDigDef_InxOut  is
GENERIC (InputLength,OutLength	: integer);
port
(
 ClockIn ,                              -- General clock
 nResetIn					                      -- General reset active low
 						: in	std_logic;
 Input 						                      -- Input number for decoding
 						: in	std_logic_vector(InputLength downto 0);
 OutputRise                             -- Outputs
 						: out	std_logic_vector(OutLength downto 0)
);
end DecoderDigDef_InxOut;

architecture  ArchDecoderDigDef_InxOut of DecoderDigDef_InxOut is
signal InputTemp  		: integer range 0 to OutLength + 1 := 0;
signal OutputSelTmp0,OutputSelTmp1
						: std_logic_vector(OutLength downto 0) := (others => '0');

begin

InputTemp <= conv_integer(Input);

DecProcess:
process(ClockIn)
begin
 if (ClockIn'event and ClockIn = '1') then
	DecLoop:
	for i in OutLength downto 0 loop
	case nResetIn is
	 when '0' =>
	  OutputSelTmp0 <= (others => '0');
	 when others =>
	 	 if InputTemp = i then
	 	  OutputSelTmp0(i) <= '1';
	 	 else
	 	  OutputSelTmp0(i) <= '0';
	 	 end if;
	 end case;
	end loop decloop;
 end if ;

 if (ClockIn'event and ClockIn = '0') then
	case nResetIn is
	 when '0' =>
	  OutputSelTmp1 <= (others => '0');
 	  OutputRise <= (others => '0');
	 when others =>
	 OutputSelTmp1 <= OutputSelTmp0;
	 OutputRise <= not OutputSelTmp1 and OutputSelTmp0;
	end case;
 end if ;

end process	DecProcess;
end ArchDecoderDigDef_InxOut;
